@@ -96,14 +96,6 @@ class Config():
     def profile(self):
         return self._profile
 
-    @profile.setter
-    def profile(self, profile):
-        if self._profile == profile:
-            return
-
-        self._profile = profile
-        self._initialize_config()
-
     @property
     def account_id(self):
         return self._account_id
